@@ -1,5 +1,5 @@
 ;; eicq-toolbar.el   -*-Emacs-Lisp-*-
-;; $Id: eicq-toolbar.el,v 1.1 2000/08/16 08:25:56 young Exp $
+;; $Id: eicq-toolbar.el,v 1.3 2001/03/01 22:34:59 youngs Exp $
 ;; Copyright (C) 2000 Steve Youngs
 
 
@@ -29,6 +29,8 @@
 ;;            A toolbar for eicq
 
 ;; Set some variables for the icon directory and files
+(eval-when-compile
+  (require 'eicq))
 
 (defvar eicq-icon-directory 
   "/usr/local/lib/xemacs/xemacs-packages/etc/eicq/"
